;; -*-scheme-*-
;;
;; serveez.scm - guile module for serveez
;;
;; Copyright (C) 2001, 2002 Stefan Jahn <stefan@lkcc.org>
;;
;; This is free software; you can redistribute it and/or modify it
;; under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.
;; 
;; This software is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.
;; 
;; You should have received a copy of the GNU General Public License
;; along with this package; see the file COPYING.  If not, write to
;; the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.
;;
;; $Id: serveez.scm,v 1.3 2002/06/01 10:43:48 ela Exp $
;;

(define-module (serveez)
  :no-backtrace)

(define (println . args) (for-each display args) (newline))
(define (printsln spacer . args)
  (for-each (lambda (x) (display x) (display spacer)) args) (newline))

;;
;; Using the library only: Extend the configuration file parser by
;; all the Serveez core API. :-)
;;

(define svz:handle '())

(define (svz:init)
  (catch 'misc-error
	 (lambda ()
	   (if (not (feature? 'serveez))
	       (begin
		 (println "Loading the Module.")
		 (set! svz:handle (dynamic-link "./.libs/libsvzguile.so"))
		 (dynamic-call "scm_init_serveez" svz:handle)
		 (svz-boot))
	       (println "Module already registered.")))
	 (lambda args #f))
  (println (if (and (dynamic-object? svz:handle) (feature? 'serveez)) 
	       "Module successfully loaded." "Module not found.")))

(define (svz:halt)
  (println "Finalizing the Module.")
  (if (dynamic-object? svz:handle)
      (begin (svz-halt)
	     (dynamic-unlink svz:handle)
	     (set! svz:handle '()))))

(export svz:init
	svz:halt

	svz:interface:list
	svz:interface:collect
	svz:interface:free
	svz:interface:add
	svz:interface:get
	
	svz:core:inet-ntoa
	svz:core:nonblock
	svz:core:block
	svz:core:cloexec
	svz:core:cork
	svz:core:connect
	svz:core:socket
	svz:core:inet-aton
	svz:core:open
	svz:core:close
	svz:core:fstat
	svz:core:fopen
	svz:core:fclose

	svz:malloc
	svz:calloc
	svz:realloc
	svz:free

	svz:hash:create
	svz:hash:destroy
	svz:hash:clear
	svz:hash:delete
	svz:hash:put
	svz:hash:get
	svz:hash:values
	svz:hash:keys
	svz:hash:size
	svz:hash:capacity
	svz:hash:contains
	svz:hash:rehash)

;; Start.
(svz:init)
